@@ -1,13 +1,13 @@
 __all__ = [
     'Sample',
     'Batch',
-    'Dataset',
-    'StreamDataset',
     'Vocab',
+    'BatchIterator',
+    'ShuffleIterator',
 ]
-__version__ = '0.0.4'
+__version__ = '0.0.5'
 
 from .batches import Batch
-from .datasets import Dataset, StreamDataset
 from .samples import Sample
+from .iterators import BatchIterator, ShuffleIterator
 from .vocab import Vocab
